import { Tab } from "@headlessui/react";
import React, { useEffect, useRef, useState } from "react";
import EmptyWishList from "./EmptyWishList";
import { useUserWishListQuery } from "../../app/features/userDashboard/apiSlice";
import useLanguage from "../../hooks/useLanguage";

function WishList() {
  const [page, setPage] = useState(1);
  const { data, error, isLoading, isFetching } = useUserWishListQuery(page);
  const observerTarget = useRef(null);

  useEffect(() => {
    const observer = new IntersectionObserver(
      (entries) => {
        if (entries[0].isIntersecting) {
          if (!isFetching && data?.orders?.total > data?.orders?.to) {
            setPage((prev) => prev + 1);
          }
        }
      },
      { threshold: 1 }
    );

    if (observerTarget.current) {
      observer.observe(observerTarget.current);
    }

    return () => {
      if (observerTarget.current) {
        observer.unobserve(observerTarget.current);
      }
    };
  }, [observerTarget, isFetching, data?.orders]);
  const language = useLanguage();
  return (
    <>
      <Tab.Panel>
        <h3 className="text-2xl text-dark-300 font-bold mb-4 notranslate">
          {language["Wishlist"]}
        </h3>
        <div className="border border-primary-100 rounded-md p-5">
          <ul className="divide-y divide-primary-100">
            {data?.wishlists?.data?.map((wish) => (
              <li
                key={wish.id}
                className="pr-4 py-3 whitespace-nowrap flex flex-col md:flex-row justify-between"
              >
                <div className="px-4 py-3 whitespace-nowrap">
                  <h4 className="text-dark-300 font-bold text-lg">
                    {wish.seller ? wish.seller.name : "name"}
                  </h4>
                  <p className="text-dark-200 text-sm notranslate">
                    {language["Warehouses"]} :{" "}
                    <span className="text-primary-200 font-medium">
                      {" "}
                      {wish.warehouse ? wish.warehouse.status : "1"}
                    </span>{" "}
                  </p>
                </div>
                <div className="px-4 py-3 whitespace-nowrap">
                  <p className="text-primary-200 text-sm notranslate">
                    {language["Ton"]}
                  </p>
                  <h4 className="font-bold text-2xl">{wish.product.qty}</h4>
                </div>
                <div className="px-4 py-3 whitespace-nowrap">
                  <p className="text-primary-200 text-sm notranslate">
                    {language["Price"]}
                  </p>
                  <h4>${wish.product.price}</h4>
                </div>
                <div className="px-4 py-3 whitespace-nowrap">
                  <button className="py-3.5 px-7 text-lg font-medium rounded-md bg-dark-300 text-white transition hover:text-dark-300 hover:bg-secondary notranslate">
                    {language["Add to Cart"]}
                  </button>
                </div>
              </li>
            ))}
          </ul>{" "}
        </div>
        {data?.wishlists?.data?.length === 0 && <EmptyWishList />}
        {isFetching ? "Loading..." : ""}
      </Tab.Panel>
      <div ref={observerTarget}></div>
    </>
  );
}

export default WishList;
